@@ -28,6 +28,8 @@ use strict;
 use warnings;
 
 
+our $VERSION = "5.0.6";
+
 
 =head2 on_db_load
 
@@ -50,3 +52,23 @@ sub on_db_load
 
 
 1;
+
+
+=head1 LICENSE
+
+This module is free software; you can redistribute it and/or modify it
+under the terms of either:
+
+a) the GNU General Public License as published by the Free Software
+Foundation; either version 2, or (at your option) any later version,
+or
+
+b) the Perl "Artistic License".
+
+=cut
+
+=head1 AUTHOR
+
+Steve Kemp <steve@steve.org.uk>
+
+=cut
