@@ -33,12 +33,18 @@ Now follows documentation on the available methods.
 
 package Chronicle::Plugin::Filter;
 
+
 use strict;
 use warnings;
 
+
+our $VERSION = "5.0.6";
+
+
 use IPC::Open2;
 use Symbol;
 
+
 =head2 on_insert
 
 The C<on_insert> method is automatically invoked when a new blog post
@@ -164,5 +170,25 @@ sub _order
     return 200;
 }
 
+
 1;
 
+
+=head1 LICENSE
+
+This module is free software; you can redistribute it and/or modify it
+under the terms of either:
+
+a) the GNU General Public License as published by the Free Software
+Foundation; either version 2, or (at your option) any later version,
+or
+
+b) the Perl "Artistic License".
+
+=cut
+
+=head1 AUTHOR
+
+Steve Kemp <steve@steve.org.uk>
+
+=cut
