@@ -22,10 +22,14 @@ Now follows documentation on the available methods.
 
 package Chronicle::Plugin::Generate::Index;
 
+
 use strict;
 use warnings;
 
 
+our $VERSION = "5.0.6";
+
+
 =head2 on_generate
 
 The C<on_generate> method is automatically invoked to generate output
@@ -72,6 +76,8 @@ sub on_generate
       print "Creating : $config->{'output'}/index.html\n";
 
     my $c = Chronicle::load_template("index.tmpl");
+    return unless ($c);
+
     $c->param( top => $config->{ 'top' } );
     $c->param( entries => $entries ) if ($entries);
     open( my $handle, ">:encoding(UTF-8)", "$config->{'output'}/index.html" ) or
@@ -82,3 +88,23 @@ sub on_generate
 
 
 1;
+
+
+=head1 LICENSE
+
+This module is free software; you can redistribute it and/or modify it
+under the terms of either:
+
+a) the GNU General Public License as published by the Free Software
+Foundation; either version 2, or (at your option) any later version,
+or
+
+b) the Perl "Artistic License".
+
+=cut
+
+=head1 AUTHOR
+
+Steve Kemp <steve@steve.org.uk>
+
+=cut
