@@ -20,13 +20,15 @@ Now follows documentation on the available methods.
 =cut
 
 
-
 package Chronicle::Plugin::Generate::Sitemap;
 
+
 use strict;
 use warnings;
 
 
+our $VERSION = "5.0.6";
+
 
 =head2 on_generate
 
@@ -113,8 +115,30 @@ sub on_generate
 
 }
 
+
 1;
 
+
+=head1 LICENSE
+
+This module is free software; you can redistribute it and/or modify it
+under the terms of either:
+
+a) the GNU General Public License as published by the Free Software
+Foundation; either version 2, or (at your option) any later version,
+or
+
+b) the Perl "Artistic License".
+
+=cut
+
+=head1 AUTHOR
+
+Steve Kemp <steve@steve.org.uk>
+
+=cut
+
+
 __DATA__
 <?xml version="1.0" encoding="UTF-8"?>
 <urlset
