@@ -33,10 +33,14 @@ Now follows documentation on the available methods.
 
 package Chronicle::Plugin::PostBuild;
 
+
 use strict;
 use warnings;
 
 
+our $VERSION = "5.0.6";
+
+
 =head2 on_generate
 
 The C<on_generate> method is automatically invoked to generate output
@@ -80,4 +84,25 @@ sub _order
     return 999;
 }
 
+
 1;
+
+
+=head1 LICENSE
+
+This module is free software; you can redistribute it and/or modify it
+under the terms of either:
+
+a) the GNU General Public License as published by the Free Software
+Foundation; either version 2, or (at your option) any later version,
+or
+
+b) the Perl "Artistic License".
+
+=cut
+
+=head1 AUTHOR
+
+Steve Kemp <steve@steve.org.uk>
+
+=cut
